{ pkgs
, lib
, config
, ... }: with lib; let
  cfg = config.passthrough.gnome;
in mkIf cfg.enable {
  dconf.settings = let
    p = "org/gnome";
    pd = "${p}/desktop";
    ps = "${p}/shell";
    pse = "${ps}/extensions";
    ptl = "${p}/terminal/legacy";
    ptlp = "${ptl}/profiles:";
  in {
    "${pd}/peripherals/mouse".natural-scroll = true;
    "${pd}/peripherals/touchpad".tap-to-click = true;
    "${p}/epiphany".ask-for-default = false;
    "${p}/evolution-data-server".migrated = true;

    "${p}/nautilus/preferences" = {
      default-folder-viewer = "icon-view";
      migrated-gtk-settings = true;
      search-filter-time-type = "last_modified";
    };

    "${pd}/background" = {
      color-shading-type = "solid";
      picture-options = "zoom";
      picture-uri = "file://${./catppuccin-nix.png}";
      picture-uri-dark = "file://${./catppuccin-nix.png}";
      primary-color = "#000000000000";
      secondary-color = "#000000000000";
    };

    "${pd}/interface" = {
      color-scheme = "prefer-dark";
      cursor-theme = "Catppuccin-Frappe-Dark-Cursors";
      font-antialiasing = "grayscale";
      font-hinting = "slight";
      gtk-theme = "Catppuccin-Frappe-Compact-Pink-Dark";
      icon-theme = "Papirus-Dark";
    };

    "${pd}/screensaver" = {
      color-shading-type = "solid";
      lock-enabled = false;
      picture-options = "zoom";
      picture-uri = "file://${./catppuccin-nix.png}";
      primary-color = "#000000000000";
      secondary-color = "#000000000000";
    };

    "${pd}/wm/preferences" = {
      action-double-click-titlebar = "toggle-maximize";
      action-middle-click-titlebar = "minimize";
      button-layout = "close,minimize,maximize:appmenu";
    };

    "${ptlp}" = {
      default = "71a9971e-e829-43a9-9b2f-4565c855d664";
      list = [
        "de8a9081-8352-4ce4-9519-5de655ad9361"
        "71a9971e-e829-43a9-9b2f-4565c855d664"
        "5083e06b-024e-46be-9cd2-892b814f1fc8"
        "95894cfd-82f7-430d-af6e-84d168bc34f5"
      ];
    };

    "${ptlp}/:5083e06b-024e-46be-9cd2-892b814f1fc8" = {
      background-color = "#24273a";
      cursor-background-color = "#f4dbd6";
      cursor-colors-set = true;
      cursor-foreground-color = "#24273a";
      foreground-color = "#cad3f5";
      highlight-background-color = "#24273a";
      highlight-colors-set = true;
      highlight-foreground-color = "#5b6078";
      palette = [
        "#494d64" "#ed8796" "#a6da95" "#eed49f"
        "#8aadf4" "#f5bde6" "#8bd5ca" "#b8c0e0"
        "#5b6078" "#ed8796" "#a6da95" "#eed49f"
        "#8aadf4" "#f5bde6" "#8bd5ca" "#a5adcb"
      ];
      use-theme-colors = false;
      visible-name = "Catppuccin Macchiato";
    };

    "${ptlp}/:71a9971e-e829-43a9-9b2f-4565c855d664" = {
      background-color = "#303446";
      cursor-background-color = "#f2d5cf";
      cursor-colors-set = true;
      cursor-foreground-color = "#303446";
      default-size-columns = 150;
      default-size-rows = 35;
      foreground-color = "#c6d0f5";
      highlight-background-color = "#303446";
      highlight-colors-set = true;
      highlight-foreground-color = "#626880";
      palette = [
        "#51576d" "#e78284" "#a6d189" "#e5c890"
        "#8caaee" "#f4b8e4" "#81c8be" "#b5bfe2"
        "#626880" "#e78284" "#a6d189" "#e5c890"
        "#8caaee" "#f4b8e4" "#81c8be" "#a5adce"
      ];
      use-theme-colors = false;
      visible-name = "Catppuccin Frappe";
    };

    "${ptlp}/:95894cfd-82f7-430d-af6e-84d168bc34f5" = {
      background-color = "#1e1e2e";
      cursor-background-color = "#f5e0dc";
      cursor-colors-set = true;
      cursor-foreground-color = "#1e1e2e";
      foreground-color = "#cdd6f4";
      highlight-background-color = "#1e1e2e";
      highlight-colors-set = true;
      highlight-foreground-color = "#585b70";
      palette = [
        "#45475a" "#f38ba8" "#a6e3a1" "#f9e2af"
        "#89b4fa" "#f5c2e7" "#94e2d5" "#bac2de"
        "#585b70" "#f38ba8" "#a6e3a1" "#f9e2af"
        "#89b4fa" "#f5c2e7" "#94e2d5" "#a6adc8"
      ];
      use-theme-colors = false;
      visible-name = "Catppuccin Mocha";
    };

    "${ptlp}/:de8a9081-8352-4ce4-9519-5de655ad9361" = {
      background-color = "#eff1f5";
      cursor-background-color = "#dc8a78";
      cursor-colors-set = true;
      cursor-foreground-color = "#eff1f5";
      foreground-color = "#4c4f69";
      highlight-background-color = "#eff1f5";
      highlight-colors-set = true;
      highlight-foreground-color = "#acb0be";
      palette = [
        "#5c5f77" "#d20f39" "#40a02b" "#df8e1d"
        "#1e66f5" "#ea76cb" "#179299" "#acb0be"
        "#6c6f85" "#d20f39" "#40a02b" "#df8e1d"
        "#1e66f5" "#ea76cb" "#179299" "#bcc0cc"
      ];
      use-theme-colors = false;
      visible-name = "Catppuccin Latte";
    };

    "${ps}" = {
      disabled-extensions = [
        "light-style@gnome-shell-extensions.gcampax.github.com"
        "places-menu@gnome-shell-extensions.gcampax.github.com"
        "windowsNavigator@gnome-shell-extensions.gcampax.github.com"
        "window-list@gnome-shell-extensions.gcampax.github.com"
        "workspace-indicator@gnome-shell-extensions.gcampax.github.com"
        "dash-to-panel@jderose9.github.com"
      ];
      enabled-extensions = [
        "user-theme@gnome-shell-extensions.gcampax.github.com"
        "apps-menu@gnome-shell-extensions.gcampax.github.com"
        "drive-menu@gnome-shell-extensions.gcampax.github.com"
        "dash-to-dock@micxgx.gmail.com"
      ];
      welcome-dialog-last-shown-version = "45.3";
    };

    "${pse}/user-theme".name = "Catppuccin-Frappe-Compact-Pink-Dark";

    "${pse}/dash-to-dock" = {
      background-opacity = 0.80000000000000004;
      dash-max-icon-size = 48;
      dock-position = "BOTTOM";
      height-fraction = 0.90000000000000002;
      multi-monitor = true;
    };

    "${pse}/dash-to-panel" = {
      animate-appicon-hover-animation-extent = ''{'RIPPLE': 4, 'PLANK': 4, 'SIMPLE': 1}'';
      appicon-margin = 0;
      appicon-padding = 4;
      available-monitors = [ 0 ];
      dot-position = "BOTTOM";
      hotkeys-overlay-combo = "TEMPORARILY";
      leftbox-padding = -1;
      panel-anchors = ''{"0":"MIDDLE"}'';
      panel-lengths=''{"0":100}'';
      panel-sizes=''{"0":42}'';
      primary-monitor = 0;
      status-icon-padding = -1;
      trans-use-custom-bg = false;
      tray-padding = -1;
      window-preview-title-position = "TOP";
    };
  };
}
